@@ -14,7 +14,9 @@ class ParserDevelopers:
     def __init__(self, parser, **kwargs):
         self._parser = parser
         self._parser_developers = self._parser.add_parser(
-            "developers", aliases=["devs"], help="Developers implement client/consumer apps and must be registered with an organization on Apigee Edge."
+            "developers",
+            aliases=["devs"],
+            help="Developers implement client/consumer apps and must be registered with an organization on Apigee Edge.",
         ).add_subparsers()
         self._parent_parser = kwargs.get("parent_parser", ParentParser())
         self._prefix_parser = kwargs.get(
