@@ -14,7 +14,9 @@ class ParserMaskconfigs:
     def __init__(self, parser, **kwargs):
         self._parser = parser
         self._parser_maskconfigs = self._parser.add_parser(
-            "maskconfigs", aliases=["masks"], help="Specify data that will be filtered out of trace sessions."
+            "maskconfigs",
+            aliases=["masks"],
+            help="Specify data that will be filtered out of trace sessions.",
         ).add_subparsers()
         self._parent_parser = kwargs.get("parent_parser", ParentParser())
         self._file_parser = kwargs.get("file_parser", FileParser())
